Digital droplet PCR measurements and metadata from a study of people living with cystic fibrosis
ddpcr.RdDigital droplet PCR measurements and metadata from a study of people living with cystic fibrosis
Format
A data frame object with 74 observations of 4 covariates.
- Value
droplet digital PCR, giving the observed total bacterial load in the sample in copies/uL
- Treatment
1 if the sample is from a subject receiving antibiotics, 0 otherwise
- SpecimenType
the body site of origin of the sample, either saliva or sputum
- Subject
an ID identifying the participant